@@ -1,8 +1,7 @@
 name = "pycromanager"
 
 from pycromanager.acquisitions import Acquisition, MagellanAcquisition, XYTiledAcquisition
-from pycromanager.core_util import CoreCallback
 from pycromanager.acq_util import start_headless, multi_d_acquisition_events
-from pycromanager.zmq import Bridge, JavaObjectShadow
 from pycromanager.data import Dataset
+from pycromanager.java_classes import *
 from ._version import __version__, version_info
